==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PracownikHistoriaHaslaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class PracownikHistoriaHaslaKey extends GenericDPSObject {
    /**
     * PRACOWNIK_HISTORIA_HASLA.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * PRACOWNIK_HISTORIA_HASLA.NR_PORZADKOWY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer nrPorzadkowy;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRACOWNIK_HISTORIA_HASLA.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PRACOWNIK_HISTORIA_HASLA.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PRACOWNIK_HISTORIA_HASLA.NR_PORZADKOWY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getNrPorzadkowy() {
        return nrPorzadkowy;
    }

    /**
     * PRACOWNIK_HISTORIA_HASLA.NR_PORZADKOWY
     *
     * @param nrPorzadkowy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrPorzadkowy(Integer nrPorzadkowy) {
        this.nrPorzadkowy = nrPorzadkowy;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PracownikHistoriaHaslaKey other = (PracownikHistoriaHaslaKey) that;
        return (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getNrPorzadkowy() == null ? other.getNrPorzadkowy() == null : this.getNrPorzadkowy().equals(other.getNrPorzadkowy()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getNrPorzadkowy() == null) ? 0 : getNrPorzadkowy().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", nrPorzadkowy=").append(nrPorzadkowy);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PracownikHistoriaHaslaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class PracownikHistoriaHaslaKey extends GenericDPSObject {
    /**
     * PRACOWNIK_HISTORIA_HASLA.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * PRACOWNIK_HISTORIA_HASLA.NR_PORZADKOWY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer nrPorzadkowy;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRACOWNIK_HISTORIA_HASLA.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PRACOWNIK_HISTORIA_HASLA.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PRACOWNIK_HISTORIA_HASLA.NR_PORZADKOWY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getNrPorzadkowy() {
        return nrPorzadkowy;
    }

    /**
     * PRACOWNIK_HISTORIA_HASLA.NR_PORZADKOWY
     *
     * @param nrPorzadkowy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrPorzadkowy(Integer nrPorzadkowy) {
        this.nrPorzadkowy = nrPorzadkowy;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PracownikHistoriaHaslaKey other = (PracownikHistoriaHaslaKey) that;
        return (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getNrPorzadkowy() == null ? other.getNrPorzadkowy() == null : this.getNrPorzadkowy().equals(other.getNrPorzadkowy()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getNrPorzadkowy() == null) ? 0 : getNrPorzadkowy().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", nrPorzadkowy=").append(nrPorzadkowy);
        sb.append("]");
        return sb.toString();
    }
}
